"""medication dispenses app."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class MedicationdispensesConfig(AppConfig):
    """Medication Dispenses Config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.medicationdispenses"
    verbose_name = _("Medication Dispenses")



"""imaging study app."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ImagingstudyConfig(AppConfig):
    """imaging study app config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.imagingstudies"
    verbose_name = _("Imaging Study")



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('claimresponses', '0003_initial'),
        ('devicerequests', '0004_initial'),
        ('medicationrequests', '0001_initial'),
        ('nutritionorders', '0001_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='claimresponseadditemproviderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_provider_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemproviderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_provider_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='claimresponseadditem',
            name='provider',
            field=models.ManyToManyField(blank=True, related_name='claim_response_add_item_provider', to='claimresponses.claimresponseadditemproviderreference'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemrequestreference',
            name='device_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_request_reference_device_request', to='devicerequests.devicerequest'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemrequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemrequestreference',
            name='medication_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_request_reference_medication_request', to='medicationrequests.medicationrequest'),
        ),
        migrations.AddField(
            model_name='claimresponseadditemrequestreference',
            name='nutrition_order',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='claim_response_add_item_request_reference_nutrition_order', to='nutritionorders.nutritionorder'),
        ),
    ]
